// scatterplot.js
export const createScatterPlot = (
  svg,
  data,
  xValue,
  yValue,
  margin,
  width,
  height,
) => {
  const x = d3
    .scaleLinear()
    .domain(d3.extent(data, xValue))
    .range([margin.left, width - margin.right]);

  const y = d3
    .scaleLinear()
    .domain(d3.extent(data, yValue))
    .range([height - margin.bottom, margin.top]);

  const marks = data.map((d) => ({
    x: x(xValue(d)),
    y: y(yValue(d)),
  }));

  svg
    .selectAll('circle')
    .data(marks)
    .enter()
    .append('circle')
    .attr('cx', (d) => d.x)
    .attr('cy', (d) => d.y)
    .attr('r', 5);

  svg
    .append('g')
    .attr('transform', `translate(${margin.left},0)`)
    .call(d3.axisLeft(y));

  svg
    .append('g')
    .attr(
      'transform',
      `translate(0,${height - margin.bottom})`,
    )
    .call(d3.axisBottom(x));

  // X Axis Label
  svg
    .append('text')
    .attr('x', width / 2)
    .attr('y', height - margin.bottom / 8)
    .attr('text-anchor', 'middle')
    .text('Horsepower');

  // Y Axis Label
  svg
    .append('text')
    .attr('transform', 'rotate(-90)')
    .attr('x', -height / 2)
    .attr('y', margin.left / 6)
    .attr('text-anchor', 'middle')
    .text('Miles per Gallon');
};
